@@ -17,6 +17,15 @@
  * Boston, MA 02110-1301, USA.
  */
 
+/**
+ * SECTION:gstaudiometa
+ * @short_description: Buffer metadata for audio downmix matrix handling
+ *
+ * #GstAudioDownmixMeta defines an audio downmix matrix to be send along with
+ * audio buffers. These functions in this module help to create and attach the
+ * meta as well as extracting it.
+ */
+
 #include <string.h>
 
 #include "gstaudiometa.h"
@@ -50,12 +59,20 @@ static gboolean
 gst_audio_downmix_meta_transform (GstBuffer * dest, GstMeta * meta,
     GstBuffer * buffer, GQuark type, gpointer data)
 {
-  GstAudioDownmixMeta *smeta;
+  GstAudioDownmixMeta *smeta, *dmeta;
 
   smeta = (GstAudioDownmixMeta *) meta;
-  gst_buffer_add_audio_downmix_meta (dest, smeta->from_position,
-      smeta->from_channels, smeta->to_position, smeta->to_channels,
-      (const gfloat **) smeta->matrix);
+
+  if (GST_META_TRANSFORM_IS_COPY (type)) {
+    dmeta = gst_buffer_add_audio_downmix_meta (dest, smeta->from_position,
+        smeta->from_channels, smeta->to_position, smeta->to_channels,
+        (const gfloat **) smeta->matrix);
+    if (!dmeta)
+      return FALSE;
+  } else {
+    /* return FALSE, if transform type is not supported */
+    return FALSE;
+  }
 
   return TRUE;
 }
@@ -70,7 +87,7 @@ gst_audio_downmix_meta_transform (GstBuffer * dest, GstMeta * meta,
  * Find the #GstAudioDownmixMeta on @buffer for the given destination
  * channel positions.
  *
- * Returns: the #GstAudioDownmixMeta on @buffer.
+ * Returns: (transfer none): the #GstAudioDownmixMeta on @buffer.
  */
 GstAudioDownmixMeta *
 gst_buffer_get_audio_downmix_meta_for_channels (GstBuffer * buffer,
@@ -103,14 +120,14 @@ gst_buffer_get_audio_downmix_meta_for_channels (GstBuffer * buffer,
  * @to_channels: The number of channels of the destination
  * @matrix: The matrix coefficients.
  *
- * Attaches GstAudioDownmixMeta metadata to @buffer with the given parameters.
+ * Attaches #GstAudioDownmixMeta metadata to @buffer with the given parameters.
  *
  * @matrix is an two-dimensional array of @to_channels times @from_channels
  * coefficients, i.e. the i-th output channels is constructed by multiplicating
  * the input channels with the coefficients in @matrix[i] and taking the sum
  * of the results.
  *
- * Returns: the #GstAudioDownmixMeta on @buffer.
+ * Returns: (transfer none): the #GstAudioDownmixMeta on @buffer.
  */
 GstAudioDownmixMeta *
 gst_buffer_add_audio_downmix_meta (GstBuffer * buffer,
